repl

package
v0.0.0-...-56748ea Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 4, 2022 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

const HEADER = "🐸 FroLang v0.1.0 REPL"
const PROMPT = ">> "

Variables

var GREEN = "\033[32m"
var RED = "\033[31m"
var RESET = "\033[0m"

Functions

func Start

func Start(in io.Reader, out io.Writer)

Creates the global environment Enters the loop Take input statement form user Lexer will tokenize the input Parser will read tokens through lexer and constructs the program AST If there were any parse errors, we will display it Else, evaluator will evaluate the program AST and displays the result Ask user for next input Ctrl + C input will terminate the loop

Types

This section is empty.

Jump to