Documentation
¶
Index ¶
Constants ¶
const HEADER = "🐸 FroLang v0.1.0 REPL"
const PROMPT = ">> "
Variables ¶
var GREEN = "\033[32m"
var RED = "\033[31m"
var RESET = "\033[0m"
Functions ¶
func Start ¶
Creates the global environment Enters the loop Take input statement form user Lexer will tokenize the input Parser will read tokens through lexer and constructs the program AST If there were any parse errors, we will display it Else, evaluator will evaluate the program AST and displays the result Ask user for next input Ctrl + C input will terminate the loop
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.